@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
+ * Copyright (c) 2007-2009 JGoodies Karsten Lentzsch. All Rights Reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -44,8 +44,7 @@ import javax.swing.border.Border;
  * in <code>#show</code> it snapshots the screen background as needed,
  * and in <code>#hide</code> it cleans up all changes made before.
  *
- * @author Andrej Golovnin
- * @version $Revision: 1.8 $
+ * @version $Revision: 1.9 $
  *
  * @see com.jgoodies.looks.common.ShadowPopupBorder
  * @see com.jgoodies.looks.common.ShadowPopupFactory
@@ -161,12 +160,13 @@ public final class ShadowPopup extends Popup {
      * horizontal and vertical drop shadows - if any.
      */
     public void hide() {
-        if (contents == null)
+        if (contents == null) {
             return;
+        }
 
         JComponent parent = (JComponent) contents.getParent();
         popup.hide();
-        if ((parent != null) && parent.getBorder() == SHADOW_BORDER) {
+        if (parent != null && parent.getBorder() == SHADOW_BORDER) {
             parent.setBorder(oldBorder);
             parent.setOpaque(oldOpaque);
             oldBorder = null;
@@ -217,11 +217,11 @@ public final class ShadowPopup extends Popup {
         // has a preferred size less than or equal to 0.
         // We can't use the size, because it is(0, 0) for new popups.
         Dimension contentsPrefSize = contents.getPreferredSize();
-        if ((contentsPrefSize.width <= 0) || (contentsPrefSize.height <= 0)) {
+        if (contentsPrefSize.width <= 0 || contentsPrefSize.height <= 0) {
             return;
         }
         for(Container p = contents.getParent(); p != null; p = p.getParent()) {
-            if ((p instanceof JWindow) || (p instanceof Panel)) {
+            if (p instanceof JWindow || p instanceof Panel) {
                 // Workaround for the gray rect problem.
                 p.setBackground(contents.getBackground());
                 heavyWeightContainer = p;
@@ -274,7 +274,7 @@ public final class ShadowPopup extends Popup {
 
             // Avoid unnecessary and illegal screen captures
             // for degenerated popups.
-            if ((width <= 0) || (height <= SHADOW_SIZE)) {
+            if (width <= 0 || height <= SHADOW_SIZE) {
                 return;
             }
 
@@ -310,10 +310,10 @@ public final class ShadowPopup extends Popup {
             RECT.width = width;
             RECT.height = SHADOW_SIZE;
 
-            if ((RECT.x + RECT.width) > layeredPaneWidth) {
+            if (RECT.x + RECT.width > layeredPaneWidth) {
                 RECT.width = layeredPaneWidth - RECT.x;
             }
-            if ((RECT.y + RECT.height) > layeredPaneHeight) {
+            if (RECT.y + RECT.height > layeredPaneHeight) {
                 RECT.height = layeredPaneHeight - RECT.y;
             }
             if (!RECT.isEmpty()) {
@@ -338,10 +338,10 @@ public final class ShadowPopup extends Popup {
             RECT.width = SHADOW_SIZE;
             RECT.height = height - SHADOW_SIZE;
 
-            if ((RECT.x + RECT.width) > layeredPaneWidth) {
+            if (RECT.x + RECT.width > layeredPaneWidth) {
                 RECT.width = layeredPaneWidth - RECT.x;
             }
-            if ((RECT.y + RECT.height) > layeredPaneHeight) {
+            if (RECT.y + RECT.height > layeredPaneHeight) {
                 RECT.height = layeredPaneHeight - RECT.y;
             }
             if (!RECT.isEmpty()) {
