@@ -55,9 +55,9 @@ import com.jgoodies.looks.common.ShadowPopupFactory;
  * 1.4.2, and 1.5 environments.
  *
  * @author Karsten Lentzsch
- * @version $Revision: 1.41 $
+ * @version $Revision: 1.43 $
  */
-public final class WindowsLookAndFeel extends com.sun.java.swing.plaf.windows.WindowsLookAndFeel {
+public class WindowsLookAndFeel extends com.sun.java.swing.plaf.windows.WindowsLookAndFeel {
 
     /**
      * An optional client property key for JMenu and JToolBar
@@ -276,7 +276,7 @@ public final class WindowsLookAndFeel extends com.sun.java.swing.plaf.windows.Wi
 
         // Aligned menu items
         if (  !LookUtils.IS_JAVA_5_OR_LATER
-           || !LookUtils.IS_OS_WINDOWS_VISTA
+           || !LookUtils.IS_OS_WINDOWS_6_OR_LATER
            || !LookUtils.IS_LAF_WINDOWS_XP_ENABLED) {
             uiDefaults = append(uiDefaults,
             "MenuItemUI",            windowsPrefix + "MenuItemUI");
@@ -291,7 +291,7 @@ public final class WindowsLookAndFeel extends com.sun.java.swing.plaf.windows.Wi
 
         if (LookUtils.IS_LAF_WINDOWS_XP_ENABLED) {
             // Aligned menu items
-            if (!LookUtils.IS_JAVA_5_OR_LATER || !LookUtils.IS_OS_WINDOWS_VISTA) {
+            if (!LookUtils.IS_JAVA_5_OR_LATER || !LookUtils.IS_OS_WINDOWS_6_OR_LATER) {
                 uiDefaults = append(uiDefaults,
                 "MenuUI",             windowsPrefix + "XPMenuUI");
             }
@@ -335,7 +335,7 @@ public final class WindowsLookAndFeel extends com.sun.java.swing.plaf.windows.Wi
 
         final boolean isXP = LookUtils.IS_LAF_WINDOWS_XP_ENABLED;
         final boolean isClassic = !isXP;
-        final boolean isVista = LookUtils.IS_OS_WINDOWS_VISTA;
+        final boolean isVista = LookUtils.IS_OS_WINDOWS_6_OR_LATER;
 
         initFontDefaults(table);
 
